__title__ = "woqlClient"
__description__ = "woqlClient library for accessing the Terminus DB API"
__url__ = ""
__version__ = "10.1.4"
__build__ = 00
__author__ = "TerminusDB group"
__author_email__ = "team@terminusdb.com"
__license__ = "GNU General Public License v3 (GPLv3)"
__copyright__ = "Copyright 2019 datachemist"
